/*
 *     Kits4me_LED_control.h 
 * lib for kitss4.me touch panel
 * function for last input
 * 
 *
 * pwm pins for arduino nano: D3,D5,D6,D9,D10,D11
 * use those pins for getting mixed colors
 * 
 * Created by Amir Dagan, Kits4.me  , Feb,2019.
*/
#include "Arduino.h"
#include "Kits4me_LED_control.h"

Kits4me_LED_control::Kits4me_LED_control(int pinR,int pinG,int pinB){
	this->_currColor=KITS_COLOR_NONE;
	this->_colorEndTime=0;
	
	this->_pinR=pinR;
	this->_pinG=pinG;
	this->_pinB=pinB;
	
	pinMode(this->_pinR, OUTPUT);
	pinMode(this->_pinG, OUTPUT);
	pinMode(this->_pinB, OUTPUT);
	
	this->turnLightOff();
}
void Kits4me_LED_control::turnLightOff(){
	this->lightTheLed(KITS_COLOR_NONE,0);
}
void Kits4me_LED_control::lightTheLed(short color,int msec){
	this->_colorEndTime=millis()+msec;
	switch(color){
		case KITS_COLOR_NONE:
							digitalWrite(this->_pinR,LOW);
							digitalWrite(this->_pinG,LOW);
							digitalWrite(this->_pinB,LOW);
							this->_currColor=KITS_COLOR_NONE;
							break;
		case KITS_COLOR_RED:
							digitalWrite(this->_pinR,HIGH);
							digitalWrite(this->_pinG,LOW);
							digitalWrite(this->_pinB,LOW);
							this->_currColor=KITS_COLOR_RED;
							break;
		case KITS_COLOR_GREEN:
							digitalWrite(this->_pinR,LOW);
							digitalWrite(this->_pinG,HIGH);
							digitalWrite(this->_pinB,LOW);
							this->_currColor=KITS_COLOR_GREEN;
							break;
		case KITS_COLOR_BLUE:
							digitalWrite(this->_pinR,LOW);
							digitalWrite(this->_pinG,LOW);
							digitalWrite(this->_pinB,HIGH);
							this->_currColor=KITS_COLOR_BLUE;
							break;
		case KITS_COLOR_YELLOW:
							digitalWrite(this->_pinR,HIGH);
							digitalWrite(this->_pinG,HIGH);
							digitalWrite(this->_pinB,LOW);
							this->_currColor=KITS_COLOR_YELLOW;
							break;
		case KITS_COLOR_PURPLE:
							digitalWrite(this->_pinR,HIGH);
							digitalWrite(this->_pinG,LOW);
							digitalWrite(this->_pinB,HIGH);
							this->_currColor=KITS_COLOR_PURPLE;
							break;
		case KITS_COLOR_WHITE:
							digitalWrite(this->_pinR,HIGH);
							digitalWrite(this->_pinG,HIGH);
							digitalWrite(this->_pinB,HIGH);
							this->_currColor=KITS_COLOR_WHITE;
							break;
		case KITS_COLOR_CYAN:
							digitalWrite(this->_pinR,LOW);
							digitalWrite(this->_pinG,HIGH);
							digitalWrite(this->_pinB,HIGH);
							this->_currColor=KITS_COLOR_CYAN;
							break;
	}
}
/*
*  this function also check if it is time to turn the light off
*/
bool Kits4me_LED_control::lightIsOff(){
	bool ret=false;
	if(millis() >= this->_colorEndTime){
		this->turnLightOff();
	}
	if(this->_currColor == KITS_COLOR_NONE){
		ret = true;
	}
	return ret;
}
short Kits4me_LED_control::currentColor(){
	return this->_currColor;
}
bool Kits4me_LED_control::isThatCurrColor(short clr){
	bool ret=false;
	if(this->_currColor == clr){
		ret = true;
	}
	return ret;
}
short Kits4me_LED_control::chooseRandomColor(short numberOfColors){
	short ret;
	if(numberOfColors < 0){
		ret=random(1,this->_maxColorNum);
	} else {
		ret=random(1,numberOfColors+1);
	}
	return ret;
}


